@@ -350,7 +350,7 @@ function unpack_runtime()
 	fi
 
 	# Make sure we haven't already unpacked them
-	if [ -f "$STEAM_RUNTIME/checksum" ] && cmp "$STEAM_RUNTIME.checksum" "$STEAM_RUNTIME/checksum" >/dev/null; then
+	if [ -f "$STEAM_RUNTIME/checksum" ] && [[ $(< "$STEAM_RUNTIME.checksum" ) = $(< "$STEAM_RUNTIME/checksum" ) ]] ; then
 		check_pins "$STEAM_RUNTIME"
 		return 0
 	fi
